@@ -89,9 +89,9 @@ def _get_public_identity_host(request):
     :return:
     """
     host = request.get_host()
-    domain_name = host.split('//')[-1]
-    parent_domain = '.'.join(domain_name.split('.')[1:])
-    return 'https://id.' + parent_domain
+    domain_name = host.split("//")[-1]
+    parent_domain = ".".join(domain_name.split(".")[1:])
+    return "https://id." + parent_domain
 
 
 @api_view(["GET"])
